@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.5.2-5
+# Application Name - Health Check V0.6.0-1
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -18,10 +18,11 @@
 #
 # files: Ensure that gn_cellinfo is in the same folder as the healthcheck.py file.
 #
+# Talk/Bugs : http://talk.maemo.org/showthread.php?t=45453
 #
 # Import the libraries needed in this program
 # Basic ones
-# import PyQt4 
+# import PyQt4 & sys
 from PyQt4 import QtCore, QtGui
 import sys
 # import osso
@@ -40,13 +41,13 @@ import gobject
 import gn_cellinfo
 import gtk
 import hildon
+import pygtk
 
 #for phone orientation call
 import dbus.glib
 
 #For bluetooth - apt-get install python-bluetooth
 #import bluetooth
-
 # osso_c = osso.Context("healthcheck", "666", True)
 
 #Threading imports!
@@ -54,13 +55,13 @@ from threading import Thread
 import time
 gtk.gdk.threads_init()
 
-import pygtk
+
 
 
 # Set a global variable - used to send the GPS info from a function back onto its label in the GUI. I'm sure there is a much better way returning
 # the variable in a function, but this works.... Example: http://www.wellho.net/resources/ex.php4?item=y105/locvar.py
 # Setting it to "location" for now.
-var_g_GPS = "location"
+var_g_GPS = "No GPS lock"
 var_g_ALT = "altitude"
 
 class Ui_MainWindow(object):
@@ -238,7 +239,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.5.2-5 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.6.0-1 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -436,7 +437,7 @@ class Ui_MainWindow(object):
         elif g.strip() == "1.2009.41-1":
             self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - Early Release Vanilla Variant")
         else:
-           self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - Varient unknown")
+           self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " ")
 
 # Funtion - update CPU Information
     def updateCPU(self):
@@ -568,15 +569,6 @@ class Ui_MainWindow(object):
         b = os.popen(bb)
         b.close()
         
-       
-        
-        #Bluetooth
-        #print "performing inquiry..."
-        #nearby_devices = bluetooth.discover_devices(lookup_names = True)
-        #print "found %d devices" % len(nearby_devices)
-        #for name, addr in nearby_devices:
-            #print "  %s - %s" % (addr, name)
-
     def updateLED(self):
         import dbus.glib
         bus = dbus.SessionBus()
@@ -712,7 +704,7 @@ class Ui_MainWindow(object):
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.2-5", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.6.0-1", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
@@ -824,7 +816,7 @@ def on_changed(device, data):
             #print device.fix
             #print device.fix[4:6]
             #Seems to struggle with doing it once.... so do it 5 times to warm it up!
-        for i in range(1, 4):
+        for i in range(1, 5):
             if device.fix[1] & location.GPS_DEVICE_LATLONG_SET:
                 var_g_GPS = "lat = %f, long = %f" % device.fix[4:6]
                 #print "horizontal accuracy: %f meters" % (device.fix[6] / 100)
